module Core.Configuration where

import Configuration.Dotenv

import System.Directory   (doesFileExist)
import System.Environment (getEnv, lookupEnv)

-- Load environment variables from dotenv file if any are missing from ENV
main :: IO ()
main = do
  reqEnvLookup <- getRequiredEnv
  if (Nothing `elem` reqEnvLookup)
    then checkEnvFile requiredEnvVars
    else pure ()
  where
    getRequiredEnv :: IO [Maybe String]
    getRequiredEnv = mapM (\s -> lookupEnv s) requiredEnvVars

    checkEnvFile :: [String] -> IO ()
    checkEnvFile requiredEnv = do
      dotEnvExists <- doesFileExist "./.env"
      if dotEnvExists
        then do
          loadFile defaultConfig
          fromEnvFile <- getRequiredEnv
          if (Nothing `elem` fromEnvFile)
             then error $ missingEnvMsg requiredEnv
             else pure ()
        else error $ "Cannot find .env file in application directory.\n"
          ++ missingEnvMsg requiredEnv

    missingEnvMsg :: [String] -> String
    missingEnvMsg required =
      "Missing required environment variable(s).\n"
      ++ "All required environment variables:\n"
      ++  unlines required

-- The port to run the web server on
port :: IO String
port = getEnv "SAMPU_PORT"

-- The site's title; used for HTML title and XML feed title
title :: IO String
title = getEnv "SAMPU_TITLE"

-- The site's public-facing base url with no trailing slash
baseUrl :: IO String
baseUrl = getEnv "SAMPU_BASEURL"

requiredEnvVars :: [String]
requiredEnvVars = [ "SAMPU_PORT", "SAMPU_TITLE", "SAMPU_BASEURL" ]
