module Core.Styles where

import           Clay           hiding (main_)
import qualified Clay.Media     as M
import           Data.Text.Lazy hiding (center)
import           Prelude        hiding (div)

cssRender :: Css -> Text
cssRender css = renderWith compact [] css

priColor, secColor, terColor :: Color
priColor = "#f1f6f0"
secColor = "#222323"
terColor = "#6D92AD"

composedStyles :: Css
composedStyles = do
  core_
  main_
  nav_
  notFound_
  postList_
  mobileFriendly_

core_ :: Css
core_ = do
  a_
  body_
  code_
  footer_
  html_
  p_

a_ :: Css
a_ = do
  a ? do
    textDecoration    none
    color             terColor

body_ :: Css
body_ = do
  body ? do
    display       flex
    minHeight   $ vh 100
    flexDirection column
    fontFamily    [] [monospace]
    fontSize    $ em 1.25
    fontWeight  $ weight 300
    textAlign     start
    margin        (em 0) auto (em 0) auto
    strong ? do
      fontWeight    $ weight 600
    li ? do
      listStyleType $ other "\"~> \""

footer_ :: Css
footer_ = do
  footer ? do
    bottom            (em 0)
    margin            auto (em 0) (em 0) (em 0)
    width           $ pct 100
    backgroundColor   terColor
    textAlign         center  
    padding           (em 1) (em 0) (em 1) (em 0)
    boxSizing         borderBox
    p ? do
      fontSize $ em 0.75
      margin     (em 0) (em 2) (em 0) (em 2)
      color      priColor
      a ? do
        color priColor

html_ :: Css
html_ = do
  html   ? do
    backgroundColor priColor
    color           secColor

p_ :: Css
p_ = do
  p ? do
    margin (em 1) (em 0) (em 0.6) (em 0)

main_ :: Css
main_ = do
  ".main" ? do
    margin     (em 0) auto (em 0) auto
    maxWidth $ pct 60
    minWidth $ pct 40

notFound_ :: Css
notFound_ = do
  ".notFound" ? do
    margin    (em 0) auto (em 0) auto
    textAlign center 
    h1 ? do
      fontSize   $ pct 500
      fontWeight $ weight 200
      color        terColor

postList_ :: Css
postList_ = do
  ".postList" ? do
    margin   (em 0) auto (em 0) auto
    fontSize (em 1.5)
    minWidth (pct 60)
    maxWidth (pct 95)
    overflow scroll

code_ :: Css
code_ = do
  code ? do
    color           priColor
    backgroundColor terColor
    overflowX       scroll

nav_ :: Css
nav_ = do
  ".navContainer" ? do
    margin      (em 1.5) (em 0) (em 1.5) (em 0)
    width     $ pct 100
    textAlign   center
  ".mainNav"      ? do
    margin      (em 0) auto (em 0) auto
    padding     (em 0.5) (em 0.5) (em 0.5) (em 0.5)
    overflow    hidden
    boxShadow . pure $ bsColor "#ccc" $ shadowWithBlur (px 4) (px 4) (px 6)
    display     inlineFlex
    li ? do
      listStyleType   none
      a ? do
        display       block
        textAlign     center
        padding       (em 0.25) (em 0.3) (em 0.25) (em 0.3)
        textTransform lowercase

mobileFriendly_ :: Css
mobileFriendly_ = query M.screen [M.maxWidth 768] $ do
  ".main" ? do
    margin     (em 1) auto (em 1) auto
    maxWidth $ pct 95
